# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

ENVIRONMENT_VARIABLES = [
    "CI",
    "BITBUCKET_BUILD_NUMBER",
    "BITBUCKET_CLONE_DIR",
    "BITBUCKET_COMMIT",
    "BITBUCKET_REPO_OWNER",
    "BITBUCKET_REPO_OWNER_UUID",
    "BITBUCKET_REPO_SLUG",
    "BITBUCKET_REPO_UUID",
    "BITBUCKET_BRANCH",
    "BITBUCKET_TAG",
    "BITBUCKET_BOOKMARK",
    "BITBUCKET_PARALLEL_STEP",
    "BITBUCKET_PARALLEL_STEP_COUNT",
]
